@@ -41,7 +41,6 @@ class ObjectId(object):
         """Generate a new value for this ObjectId.
         """
         # TODO for now, just generate 12 random bytes. this will change when we decide on an _id algorithm...
-        self.__new = True
         oid = ""
         for _ in range(12):
             oid += chr(random.randint(0, 255))
@@ -57,7 +56,6 @@ class ObjectId(object):
         Arguments:
         - `id`: a valid ObjectId
         """
-        self.__new = False
         if isinstance(oid, ObjectId):
             self.__id = oid.__id
         elif isinstance(oid, types.StringType):
@@ -78,11 +76,3 @@ class ObjectId(object):
         if isinstance(other, ObjectId):
             return cmp(self.__id, other.__id)
         return NotImplemented
-
-    def _use(self):
-        self.__new = False
-
-    def is_new(self):
-        """Return True if this ObjectId has not been used as an _id field.
-        """
-        return self.__new
