@@ -19,8 +19,10 @@ import datetime
 import re
 import glob
 import sys
+import types
 
 import qcheck
+from pymongo.binary import Binary
 from pymongo.objectid import ObjectId
 from pymongo.dbref import DBRef
 from pymongo.son import SON
@@ -76,7 +78,7 @@ class TestBSON(unittest.TestCase):
                          "\x11\x00\x00\x00\x04\x65\x6D\x70\x74\x79\x00\x05\x00\x00\x00\x00\x00")
         self.assertEqual(BSON.from_dict({"none": {}}),
                          "\x10\x00\x00\x00\x03\x6E\x6F\x6E\x65\x00\x05\x00\x00\x00\x00\x00")
-        self.assertEqual(BSON.from_dict({"test": "test"}),
+        self.assertEqual(BSON.from_dict({"test": Binary("test")}),
                          "\x18\x00\x00\x00\x05\x74\x65\x73\x74\x00\x08\x00\x00\x00\x02\x04\x00\x00\x00\x74\x65\x73\x74\x00")
         self.assertEqual(BSON.from_dict({"test": None}),
                          "\x0B\x00\x00\x00\x0A\x74\x65\x73\x74\x00\x00")
@@ -100,6 +102,8 @@ class TestBSON(unittest.TestCase):
             self.assertEqual(dict, (BSON.from_dict(dict)).to_dict())
         helper({})
         helper({"test": u"hello"})
+        self.assertTrue(isinstance(BSON.from_dict({"hello": "world"}).to_dict()["hello"],
+                                   types.UnicodeType))
         helper({"mike": -10120})
         helper({u"hello": 0.0013109})
         helper({"something": True})
